@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def preview(vmanage, policyassembly):
     """
     Get policy assembly preview
@@ -14,8 +11,8 @@ def preview(vmanage, policyassembly):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/assembly/vedge"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policyassembly)
+    endpoint = f"dataservice/template/policy/assembly/vedge"
+    response = vmanage.apiCall("POST", endpoint, policyassembly)
     return response
 
 def previewById(vmanage, id):
@@ -31,6 +28,6 @@ def previewById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/assembly/vedge/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/assembly/vedge/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
