@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def generateChangePartitionInfo(vmanage, deviceId):
     """
     Get change partition information
@@ -14,8 +11,8 @@ def generateChangePartitionInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/changepartition?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/changepartition?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def processChangePartition(vmanage, payload):
@@ -31,8 +28,8 @@ def processChangePartition(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/changepartition"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/changepartition"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def generateDeactivateInfo(vmanage, deviceId):
@@ -48,8 +45,8 @@ def generateDeactivateInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/deactivate?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/deactivate?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def processDeactivateSmu(vmanage, request):
@@ -65,8 +62,8 @@ def processDeactivateSmu(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/deactivate"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/device/action/deactivate"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def processDefaultPartition(vmanage, request):
@@ -82,8 +79,8 @@ def processDefaultPartition(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/defaultpartition"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/device/action/defaultpartition"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def createFilterVPNList(vmanage):
@@ -98,8 +95,8 @@ def createFilterVPNList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/filter/vpn"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/filter/vpn"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def generateInstallInfo(vmanage, deviceId):
@@ -115,8 +112,8 @@ def generateInstallInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/install?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/install?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def processInstall(vmanage, payload):
@@ -132,8 +129,8 @@ def processInstall(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/install"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/install"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def generateDeviceList(vmanage, deviceType, groupId):
@@ -150,8 +147,8 @@ def generateDeviceList(vmanage, deviceType, groupId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/install/devices/{deviceType}?groupId={groupId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/install/devices/{deviceType}?groupId={groupId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def generateDeviceActionList(vmanage):
@@ -166,8 +163,8 @@ def generateDeviceActionList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/list"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/list"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def processLxcActivate(vmanage, payload):
@@ -183,8 +180,8 @@ def processLxcActivate(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/lxcactivate"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/lxcactivate"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def processLxcDelete(vmanage, payload):
@@ -200,8 +197,8 @@ def processLxcDelete(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/lxcdelete"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/lxcdelete"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def processLxcInstall(vmanage, payload):
@@ -217,8 +214,8 @@ def processLxcInstall(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/lxcinstall"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/lxcinstall"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def processLxcReload(vmanage, payload):
@@ -234,8 +231,8 @@ def processLxcReload(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/lxcreload"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/lxcreload"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def processLxcReset(vmanage, payload):
@@ -251,8 +248,8 @@ def processLxcReset(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/lxcreset"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/lxcreset"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def processLxcUpgrade(vmanage, payload):
@@ -268,8 +265,8 @@ def processLxcUpgrade(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/lxcupgrade"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/lxcupgrade"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def generateRebootInfo(vmanage, deviceId):
@@ -285,8 +282,8 @@ def generateRebootInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/reboot?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/reboot?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def processReboot(vmanage, payload):
@@ -302,8 +299,8 @@ def processReboot(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/reboot"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/reboot"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def generateRebootDeviceList(vmanage, deviceType, deviceId):
@@ -320,8 +317,8 @@ def generateRebootDeviceList(vmanage, deviceType, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/reboot/devices/{deviceType}?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/reboot/devices/{deviceType}?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def generateRediscoverInfo(vmanage):
@@ -336,8 +333,8 @@ def generateRediscoverInfo(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/rediscover"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/rediscover"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def reDiscoverDevices(vmanage, payload):
@@ -353,8 +350,8 @@ def reDiscoverDevices(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/rediscover"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/rediscover"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def reDiscoverAllDevice(vmanage, payload):
@@ -370,8 +367,8 @@ def reDiscoverAllDevice(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/rediscoverall"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/rediscoverall"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def generateRemovePartitionInfo(vmanage, deviceId):
@@ -387,8 +384,8 @@ def generateRemovePartitionInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/removepartition?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/removepartition?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def processRemovePartition(vmanage, payload):
@@ -404,8 +401,8 @@ def processRemovePartition(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/removepartition"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/removepartition"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def processDeleteAmpApiKey(vmanage, uuid):
@@ -421,8 +418,8 @@ def processDeleteAmpApiKey(vmanage, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/security/amp/apikey/{uuid}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/device/action/security/amp/apikey/{uuid}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
 
 def processAmpApiReKey(vmanage, payload):
@@ -438,8 +435,8 @@ def processAmpApiReKey(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/security/amp/rekey"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/security/amp/rekey"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def testApiKey(vmanage, uuid):
@@ -455,8 +452,8 @@ def testApiKey(vmanage, uuid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/security/apikey/{uuid}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/security/apikey/{uuid}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def generateSecurityDevicesList(vmanage, policyType, groupId):
@@ -473,8 +470,8 @@ def generateSecurityDevicesList(vmanage, policyType, groupId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/security/devices/{policyType}?groupId={groupId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/security/devices/{policyType}?groupId={groupId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def triggerPendingTasksMonitoring(vmanage):
@@ -489,8 +486,8 @@ def triggerPendingTasksMonitoring(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/startmonitor"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/startmonitor"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def testIoxConfig(vmanage, deviceIP):
@@ -506,8 +503,8 @@ def testIoxConfig(vmanage, deviceIP):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/test/ioxconfig/{deviceIP}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/test/ioxconfig/{deviceIP}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createUniqueVPNList(vmanage, deviceips):
@@ -523,8 +520,8 @@ def createUniqueVPNList(vmanage, deviceips):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/uniquevpnlist"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, deviceips)
+    endpoint = f"dataservice/device/action/uniquevpnlist"
+    response = vmanage.apiCall("POST", endpoint, deviceips)
     return response
 
 def processVnfInstall(vmanage, payload):
@@ -540,8 +537,8 @@ def processVnfInstall(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/vnfinstall"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/vnfinstall"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def createVPNList(vmanage):
@@ -556,8 +553,8 @@ def createVPNList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/vpn"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/vpn"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getZTPUpgradeConfig(vmanage):
@@ -572,8 +569,8 @@ def getZTPUpgradeConfig(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/ztp/upgrade"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/ztp/upgrade"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def processZTPUpgradeConfig(vmanage, ztpConfig):
@@ -589,8 +586,8 @@ def processZTPUpgradeConfig(vmanage, ztpConfig):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/ztp/upgrade"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, ztpConfig)
+    endpoint = f"dataservice/device/action/ztp/upgrade"
+    response = vmanage.apiCall("POST", endpoint, ztpConfig)
     return response
 
 def getZTPUpgradeConfigSetting(vmanage):
@@ -605,8 +602,8 @@ def getZTPUpgradeConfigSetting(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/ztp/upgrade/setting"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/ztp/upgrade/setting"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def processZTPUpgradeConfigSetting(vmanage, ztpSetting):
@@ -622,6 +619,6 @@ def processZTPUpgradeConfigSetting(vmanage, ztpSetting):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/ztp/upgrade/setting"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, ztpSetting)
+    endpoint = f"dataservice/device/action/ztp/upgrade/setting"
+    response = vmanage.apiCall("POST", endpoint, ztpSetting)
     return response
