@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def pushConfigs(vmanage, config, nmsId):
     """
     Push device configs
@@ -15,6 +12,6 @@ def pushConfigs(vmanage, config, nmsId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/partner/wcm/netconf/{nmsId}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, config)
+    endpoint = f"dataservice/partner/wcm/netconf/{nmsId}"
+    response = vmanage.apiCall("POST", endpoint, config)
     return response
