@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getAttached(vmanage, deviceId):
     """
     Get App hosting attached device from device
@@ -14,8 +11,8 @@ def getAttached(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app-hosting/attached-devices?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app-hosting/attached-devices?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDetails(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getDetails(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app-hosting/details?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app-hosting/details?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getGuestRoutes(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getGuestRoutes(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app-hosting/guest-routes?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app-hosting/guest-routes?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNetworkDevices(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getNetworkDevices(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app-hosting/network-interfaces?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app-hosting/network-interfaces?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNetworkUtils(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getNetworkUtils(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app-hosting/network-utilization?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app-hosting/network-utilization?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getProcesses(vmanage, deviceId):
     """
@@ -94,8 +91,8 @@ def getProcesses(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app-hosting/processes?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app-hosting/processes?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStorageUtils(vmanage, deviceId):
     """
@@ -110,8 +107,8 @@ def getStorageUtils(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app-hosting/storage-utilization?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app-hosting/storage-utilization?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUtilization(vmanage, deviceId):
     """
@@ -126,6 +123,6 @@ def getUtilization(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app-hosting/utilization?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app-hosting/utilization?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
