@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getHputStats(vmanage, deviceId):
     """
     Get Appqoe Hput Statistics from device
@@ -14,8 +11,8 @@ def getHputStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/appqoe-hput-stats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/appqoe-hput-stats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNatStats(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getNatStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/appqoe-nat-stats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/appqoe-nat-stats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRmResources(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getRmResources(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/appqoe-rm-resource?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/appqoe-rm-resource?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRMStats(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getRMStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/appqoe-rm-stats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/appqoe-rm-stats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getServicesStatus(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getServicesStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/appqoe-services-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/appqoe-services-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSppiPipeStats(vmanage, deviceId):
     """
@@ -94,8 +91,8 @@ def getSppiPipeStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/appqoe-sppi-pipe-resource?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/appqoe-sppi-pipe-resource?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSppiQueueStats(vmanage, deviceId):
     """
@@ -110,8 +107,8 @@ def getSppiQueueStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/appqoe-sppi-queue-resource?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/appqoe-sppi-queue-resource?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getClusterSummary(vmanage, deviceId):
     """
@@ -126,8 +123,8 @@ def getClusterSummary(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/cluster-summary?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/cluster-summary?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getErrorRecent(vmanage, deviceId):
     """
@@ -142,8 +139,8 @@ def getErrorRecent(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/error-recent?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/error-recent?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getFlowClosedError(vmanage, deviceId):
     """
@@ -158,8 +155,8 @@ def getFlowClosedError(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/flow-closed-error?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/flow-closed-error?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getServiceControllers(vmanage, deviceId):
     """
@@ -174,8 +171,8 @@ def getServiceControllers(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/service-controllers?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/service-controllers?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatus(vmanage, deviceId):
     """
@@ -190,6 +187,6 @@ def getStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/appqoe/status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/appqoe/status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
