@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getGlobalDropStats(vmanage, deviceId):
     """
     Get SD-WAN global drop statistics detail from device (Real Time)
@@ -14,8 +11,8 @@ def getGlobalDropStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/sdwan-global-drop-statistics?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/sdwan-global-drop-statistics?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStats(vmanage, deviceId):
     """
@@ -30,6 +27,6 @@ def getStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/sdwan-stats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/sdwan-stats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
