@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getUmbrella(vmanage, deviceId):
     """
     Get SIG Umbrella tunnels from device
@@ -14,8 +11,8 @@ def getUmbrella(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/sig/umbrella/tunnels?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/sig/umbrella/tunnels?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getZscaler(vmanage, deviceId):
     """
@@ -30,6 +27,6 @@ def getZscaler(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/sig/zscaler/tunnels?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/sig/zscaler/tunnels?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
