@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def createSmuList(vmanage, deviceId):
     """
     Get software list from device
@@ -14,8 +11,8 @@ def createSmuList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/smu?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/smu?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def createSyncedSmuList(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def createSyncedSmuList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/smu/synced?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/smu/synced?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSoftwareList(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getSoftwareList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/software?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/software?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSyncedSoftwareList(vmanage, deviceId):
     """
@@ -62,6 +59,6 @@ def getSyncedSoftwareList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/software/synced?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/software/synced?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
