@@ -1,7 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
-    
 def getWorkflows(vmanage, type, id):
     """
     List all workflows for the given tenant
@@ -16,8 +12,8 @@ def getWorkflows(vmanage, type, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/workflow?type={type}&id={id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/workflow?type={type}&id={id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def saveWorkflow(vmanage, payload):
     """
@@ -32,8 +28,8 @@ def saveWorkflow(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/workflow"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, payload)
+    endpoint = f"dataservice/workflow"
+    response = vmanage.apiCall("PUT", endpoint, payload)
     return response
 def createWorkflow(vmanage, payload):
     """
@@ -48,8 +44,8 @@ def createWorkflow(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/workflow"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/workflow"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def deleteWorkflow(vmanage, payload, id):
     """
@@ -65,6 +61,6 @@ def deleteWorkflow(vmanage, payload, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/workflow?id={id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint, payload)
+    endpoint = f"dataservice/workflow?id={id}"
+    response = vmanage.apiCall("DELETE", endpoint, payload)
     return response
